Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2463)

Unified Diff: sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart

Issue 1135653005: dart2js: Cleanups and renames in runtime code that thouches types. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments. Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/compiler/js_lib/js_rti.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart
diff --git a/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart b/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart
index 83cc9c26e56322565ec19066e04d91ee72a6fb30..03fcf72fed5f50e945b1eb69db0217ea4ad9165d 100644
--- a/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart
+++ b/sdk/lib/_internal/compiler/js_lib/shared/embedded_names.dart
@@ -104,16 +104,16 @@ enum JsBuiltin {
/// ...
dartObjectConstructor,
/// Returns the class name given an [isCheckProperty].
///
/// This relies on a deterministic encoding of is-check properties (for
/// example `$isFoo` for a class `Foo`). In minified code the returned
/// classname is the minified name of the class.
///
/// JS_BUILTIN('returns:String;depends:none;effects:none',
- /// JsBuiltin.classNameFromIsCheckProperty,
+ /// JsBuiltin.isCheckPropertyToJsConstructorName,
/// isCheckProperty);
- classNameFromIsCheckProperty,
+ isCheckPropertyToJsConstructorName,
/// Returns true if the given type is a function type. Returns false for
/// the one `Function` type singleton. (See [isFunctionTypeSingleton]).
@@ -124,12 +124,12 @@ enum JsBuiltin {
/// Returns a new function type object.
///
/// JS_BUILTIN('=Object', JsBuiltin.createFunctionType)
- createFunctionType,
+ createFunctionTypeRti,
- /// Returns the class name of the given type.
+ /// Returns the JavaScript-constructor name given an rti encoding.
///
- /// JS_BUILTIN('String', JsBuiltin.typeName, type)
- typeName,
+ /// JS_BUILTIN('String', JsBuiltin.rawRtiToJsConstructorName, rti)
+ rawRtiToJsConstructorName,
/// Returns the raw runtime type of the given object. The given argument
/// [o] should be the interceptor (for non-Dart objects).
« no previous file with comments | « sdk/lib/_internal/compiler/js_lib/js_rti.dart ('k') | no next file » | no next file with comments »
@@ -104,16 +104,16 @@ enum JsBuiltin {
/// ...
dartObjectConstructor,
- /// Returns the class name given an [isCheckProperty].
+ /// Returns the JavaScript-constructor name given an [isCheckProperty].
///
/// This relies on a deterministic encoding of is-check properties (for

Powered by Google App Engine
This is Rietveld 408576698